@@ -1,7 +1,8 @@
 # Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved
 import os
 import sys
-from typing import List, Optional
+import zipfile
+from typing import Any, List, Optional
 
 from omegaconf import OmegaConf
 
@@ -29,34 +30,36 @@ class ImportlibResourcesConfigSource(ConfigSource):
     def scheme() -> str:
         return "pkg"
 
-    def load_config(
-        self,
-        config_path: str,
-        is_primary_config: bool,
-        package_override: Optional[str] = None,
-    ) -> ConfigResult:
+    def _read_config(self, res: Any) -> ConfigResult:
+        try:
+            if sys.version_info[0:2] >= (3, 8) and isinstance(res, zipfile.Path):
+                # zipfile does not support encoding, read() calls returns bytes.
+                f = res.open()
+            else:
+                f = res.open(encoding="utf-8")
+            header_text = f.read(512)
+            if isinstance(header_text, bytes):
+                # if header is bytes, utf-8 decode (zipfile path)
+                header_text = header_text.decode("utf-8")
+            header = ConfigSource._get_header_dict(header_text)
+            f.seek(0)
+            cfg = OmegaConf.load(f)
+            return ConfigResult(
+                config=cfg,
+                path=f"{self.scheme()}://{self.path}",
+                provider=self.provider,
+                header=header,
+            )
+        finally:
+            f.close()
+
+    def load_config(self, config_path: str) -> ConfigResult:
         normalized_config_path = self._normalize_file_name(config_path)
         res = resources.files(self.path).joinpath(normalized_config_path)  # type:ignore
         if not res.exists():
             raise ConfigLoadError(f"Config not found : {normalized_config_path}")
 
-        with res.open(encoding="utf-8") as f:
-            header_text = f.read(512)
-            header = ConfigSource._get_header_dict(header_text)
-            self._update_package_in_header(
-                header=header,
-                normalized_config_path=normalized_config_path,
-                is_primary_config=is_primary_config,
-                package_override=package_override,
-            )
-            f.seek(0)
-            cfg = OmegaConf.load(f)
-            return ConfigResult(
-                config=self._embed_config(cfg, header["package"]),
-                path=f"{self.scheme()}://{self.path}",
-                provider=self.provider,
-                header=header,
-            )
+        return self._read_config(res)
 
     def available(self) -> bool:
         try:
