@@ -1,30 +1,26 @@
 # Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved
 import argparse
-import copy
 import inspect
 import logging.config
 import os
 import sys
-import warnings
 from dataclasses import dataclass
 from os.path import dirname, join, normpath, realpath
 from traceback import print_exc, print_exception
-from types import FrameType
-from typing import Any, Callable, List, Optional, Sequence, Tuple, Type, Union
+from types import FrameType, TracebackType
+from typing import Any, Callable, List, Optional, Sequence, Tuple, Union
 
-from omegaconf import DictConfig, OmegaConf, read_write
-from omegaconf._utils import get_ref_type
 from omegaconf.errors import OmegaConfBaseException
 
 from hydra._internal.config_search_path_impl import ConfigSearchPathImpl
 from hydra.core.config_search_path import ConfigSearchPath, SearchPathQuery
-from hydra.core.utils import get_valid_filename, split_config_path
+from hydra.core.utils import get_valid_filename, validate_config_path
 from hydra.errors import (
     CompactHydraException,
     InstantiationException,
     SearchPathException,
 )
-from hydra.types import ObjectConf, TaskFunction
+from hydra.types import TaskFunction
 
 log = logging.getLogger(__name__)
 
@@ -120,14 +116,15 @@ def compute_search_path_dir(
     calling_file: Optional[str],
     calling_module: Optional[str],
     config_path: Optional[str],
-) -> str:
+) -> Optional[str]:
     if calling_file is not None:
         abs_base_dir = realpath(dirname(calling_file))
 
         if config_path is not None:
             search_path_dir = join(abs_base_dir, config_path)
         else:
-            search_path_dir = abs_base_dir
+            return None
+
         search_path_dir = normpath(search_path_dir)
     elif calling_module is not None:
         last_dot = calling_module.rfind(".")
@@ -159,6 +156,22 @@ def compute_search_path_dir(
     return search_path_dir
 
 
+def is_under_debugger() -> bool:
+    """
+    Attempts to detect if running under a debugger
+    """
+    frames = inspect.stack()
+    if len(frames) >= 3:
+        filename = frames[-3].filename
+        if filename.endswith("/pdb.py"):
+            return True
+        elif filename.endswith("/pydevd.py"):
+            return True
+
+    # unknown debugging will sometimes set sys.trace
+    return sys.gettrace() is not None
+
+
 def create_automatic_config_search_path(
     calling_file: Optional[str],
     calling_module: Optional[str],
@@ -197,77 +210,88 @@ def run_and_report(func: Any) -> Any:
     try:
         return func()
     except Exception as ex:
-        if _is_env_set("HYDRA_FULL_ERROR"):
+        if _is_env_set("HYDRA_FULL_ERROR") or is_under_debugger():
             raise ex
         else:
-            if isinstance(ex, CompactHydraException):
-                sys.stderr.write(str(ex) + os.linesep)
-                if isinstance(ex.__cause__, OmegaConfBaseException):
-                    sys.stderr.write(str(ex.__cause__) + os.linesep)
-            else:
-                # Custom printing that strips the Hydra related stack frames from the top
-                # And any omegaconf frames from the bottom.
-                # It is possible to add additional libraries to sanitize from the bottom later,
-                # maybe even make it configurable.
-                tb: Any = ex.__traceback__
-                search_max = 10
-                # strip Hydra frames from start of stack
-                # will strip until it hits run_job()
-                while search_max > 0:
-                    if tb is None:
-                        break
-                    frame = tb.tb_frame
-                    tb = tb.tb_next
-                    search_max = search_max - 1
-                    if inspect.getframeinfo(frame).function == "run_job":
-                        break
+            try:
+                if isinstance(ex, CompactHydraException):
+                    sys.stderr.write(str(ex) + os.linesep)
+                    if isinstance(ex.__cause__, OmegaConfBaseException):
+                        sys.stderr.write(str(ex.__cause__) + os.linesep)
+                else:
+                    # Custom printing that strips the Hydra related stack frames from the top
+                    # And any omegaconf frames from the bottom.
+                    # It is possible to add additional libraries to sanitize from the bottom later,
+                    # maybe even make it configurable.
 
-                if search_max == 0 or tb is None:
-                    # could not detect run_job, probably a runtime exception before we got there.
-                    # do not sanitize the stack trace.
-                    print_exc()
-                    sys.exit(1)
+                    tb = ex.__traceback__
+                    search_max = 10
+                    # strip Hydra frames from start of stack
+                    # will strip until it hits run_job()
+                    while search_max > 0:
+                        if tb is None:
+                            break
+                        frame = tb.tb_frame
+                        tb = tb.tb_next
+                        search_max = search_max - 1
+                        if inspect.getframeinfo(frame).function == "run_job":
+                            break
 
-                # strip OmegaConf frames from bottom of stack
-                end = tb
-                num_frames = 0
-                while end is not None:
-                    frame = end.tb_frame
-                    mdl = inspect.getmodule(frame)
-                    assert mdl is not None
-                    name = mdl.__name__
-                    if name.startswith("omegaconf."):
-                        break
-                    end = end.tb_next
-                    num_frames = num_frames + 1
+                    if search_max == 0 or tb is None:
+                        # could not detect run_job, probably a runtime exception before we got there.
+                        # do not sanitize the stack trace.
+                        print_exc()
+                        sys.exit(1)
 
-                @dataclass
-                class FakeTracebackType:
-                    tb_next: Any = None  # Optional[FakeTracebackType]
-                    tb_frame: Optional[FrameType] = None
-                    tb_lasti: Optional[int] = None
-                    tb_lineno: Optional[int] = None
+                    # strip OmegaConf frames from bottom of stack
+                    end: Optional[TracebackType] = tb
+                    num_frames = 0
+                    while end is not None:
+                        frame = end.tb_frame
+                        mdl = inspect.getmodule(frame)
+                        assert mdl is not None
+                        name = mdl.__name__
+                        if name.startswith("omegaconf."):
+                            break
+                        end = end.tb_next
+                        num_frames = num_frames + 1
 
-                iter_tb = tb
-                final_tb = FakeTracebackType()
-                cur = final_tb
-                added = 0
-                while True:
-                    cur.tb_lasti = iter_tb.tb_lasti
-                    cur.tb_lineno = iter_tb.tb_lineno
-                    cur.tb_frame = iter_tb.tb_frame
+                    @dataclass
+                    class FakeTracebackType:
+                        tb_next: Any = None  # Optional["FakeTracebackType"]
+                        tb_frame: Optional[FrameType] = None
+                        tb_lasti: Optional[int] = None
+                        tb_lineno: Optional[int] = None
 
-                    if added == num_frames - 1:
-                        break
-                    added = added + 1
-                    cur.tb_next = FakeTracebackType()
-                    cur = cur.tb_next
-                    iter_tb = iter_tb.tb_next
+                    iter_tb = tb
+                    final_tb = FakeTracebackType()
+                    cur = final_tb
+                    added = 0
+                    while True:
+                        cur.tb_lasti = iter_tb.tb_lasti
+                        cur.tb_lineno = iter_tb.tb_lineno
+                        cur.tb_frame = iter_tb.tb_frame
 
-                print_exception(etype=None, value=ex, tb=final_tb)  # type: ignore
-            sys.stderr.write(
-                "\nSet the environment variable HYDRA_FULL_ERROR=1 for a complete stack trace.\n"
-            )
+                        if added == num_frames - 1:
+                            break
+                        added = added + 1
+                        cur.tb_next = FakeTracebackType()
+                        cur = cur.tb_next
+                        assert iter_tb.tb_next is not None
+                        iter_tb = iter_tb.tb_next
+
+                    print_exception(etype=None, value=ex, tb=final_tb)  # type: ignore
+                sys.stderr.write(
+                    "\nSet the environment variable HYDRA_FULL_ERROR=1 for a complete stack trace.\n"
+                )
+            except Exception as ex2:
+                sys.stderr.write(
+                    "An error occurred during Hydra's exception formatting:"
+                    + os.linesep
+                    + repr(ex2)
+                    + os.linesep
+                )
+                raise ex
         sys.exit(1)
 
 
@@ -276,7 +300,6 @@ def _run_hydra(
     task_function: TaskFunction,
     config_path: Optional[str],
     config_name: Optional[str],
-    strict: Optional[bool],
 ) -> None:
 
     from hydra.core.global_hydra import GlobalHydra
@@ -296,10 +319,10 @@ def _run_hydra(
         task_name,
     ) = detect_calling_file_or_module_from_task_function(task_function)
 
-    config_dir, config_name = split_config_path(config_path, config_name)
+    validate_config_path(config_path)
 
     search_path = create_automatic_config_search_path(
-        calling_file, calling_module, config_dir
+        calling_file, calling_module, config_path
     )
 
     def add_conf_dir() -> None:
@@ -318,7 +341,7 @@ def _run_hydra(
     run_and_report(add_conf_dir)
     hydra = run_and_report(
         lambda: Hydra.create_main_hydra2(
-            task_name=task_name, config_search_path=search_path, strict=strict
+            task_name=task_name, config_search_path=search_path
         )
     )
 
@@ -326,19 +349,27 @@ def _run_hydra(
         if args.help:
             hydra.app_help(config_name=config_name, args_parser=args_parser, args=args)
             sys.exit(0)
+        has_show_cfg = args.cfg is not None
+        if args.resolve and (not has_show_cfg and not args.help):
+            raise ValueError(
+                "The --resolve flag can only be used in conjunction with --cfg or --help"
+            )
         if args.hydra_help:
             hydra.hydra_help(
                 config_name=config_name, args_parser=args_parser, args=args
             )
             sys.exit(0)
 
-        has_show_cfg = args.cfg is not None
         num_commands = (
-            args.run + has_show_cfg + args.multirun + args.shell_completion + args.info
+            args.run
+            + has_show_cfg
+            + args.multirun
+            + args.shell_completion
+            + (args.info is not None)
         )
         if num_commands > 1:
             raise ValueError(
-                "Only one of --run, --multirun,  -cfg, --info and --shell_completion can be specified"
+                "Only one of --run, --multirun, --cfg, --info and --shell_completion can be specified"
             )
         if num_commands == 0:
             args.run = True
@@ -365,6 +396,7 @@ def _run_hydra(
                     overrides=args.overrides,
                     cfg_type=args.cfg,
                     package=args.package,
+                    resolve=args.resolve,
                 )
             )
         elif args.shell_completion:
@@ -374,7 +406,9 @@ def _run_hydra(
                 )
             )
         elif args.info:
-            hydra.show_info(config_name=config_name, overrides=args.overrides)
+            hydra.show_info(
+                args.info, config_name=config_name, overrides=args.overrides
+            )
         else:
             sys.stderr.write("Command not specified\n")
             sys.exit(1)
@@ -404,6 +438,7 @@ def _get_completion_help() -> str:
             completion_info.append(head)
             completion_info.append(plugin_cls.help(cmd).format(_get_exec_command()))
         completion_info.append("")
+
     completion_help = "\n".join([f"    {x}" if x else x for x in completion_info])
     return completion_help
 
@@ -432,6 +467,11 @@ def get_args_parser() -> argparse.ArgumentParser:
         choices=["job", "hydra", "all"],
         help="Show config instead of running [job|hydra|all]",
     )
+    parser.add_argument(
+        "--resolve",
+        action="store_true",
+        help="Used in conjunction with --cfg, resolve config interpolations before printing.",
+    )
 
     parser.add_argument("--package", "-p", help="Config package to show")
 
@@ -444,11 +484,16 @@ def get_args_parser() -> argparse.ArgumentParser:
         help="Run multiple jobs with the configured launcher and sweeper",
     )
 
+    # defer building the completion help string until we actually need to render it
+    class LazyCompletionHelp:
+        def __repr__(self) -> str:
+            return f"Install or Uninstall shell completion:\n{_get_completion_help()}"
+
     parser.add_argument(
         "--shell-completion",
         "-sc",
         action="store_true",
-        help=f"Install or Uninstall shell completion:\n{_get_completion_help()}",
+        help=LazyCompletionHelp(),  # type: ignore
     )
 
     parser.add_argument(
@@ -470,8 +515,22 @@ def get_args_parser() -> argparse.ArgumentParser:
         help="Adds an additional config dir to the config search path",
     )
 
+    info_choices = [
+        "all",
+        "config",
+        "defaults",
+        "defaults-tree",
+        "plugins",
+        "searchpath",
+    ]
     parser.add_argument(
-        "--info", "-i", action="store_true", help="Print Hydra information"
+        "--info",
+        "-i",
+        const="all",
+        nargs="?",
+        action="store",
+        choices=info_choices,
+        help=f"Print Hydra information [{'|'.join(info_choices)}]",
     )
     return parser
 
@@ -492,24 +551,6 @@ def get_column_widths(matrix: List[List[str]]) -> List[int]:
     return widths
 
 
-def _instantiate_class(
-    clazz: Type[Any], config: Union[ObjectConf, DictConfig], *args: Any, **kwargs: Any
-) -> Any:
-    # TODO: pull out to caller?
-    final_kwargs = _get_kwargs(config, **kwargs)
-    return clazz(*args, **final_kwargs)
-
-
-def _call_callable(
-    fn: Callable[..., Any],
-    config: Union[ObjectConf, DictConfig],
-    *args: Any,
-    **kwargs: Any,
-) -> Any:
-    final_kwargs = _get_kwargs(config, **kwargs)
-    return fn(*args, **final_kwargs)
-
-
 def _locate(path: str) -> Union[type, Callable[..., Any]]:
     """
     Locate an object by name or dotted path, importing as necessary.
@@ -558,81 +599,14 @@ def _locate(path: str) -> Union[type, Callable[..., Any]]:
         raise ValueError(f"Invalid type ({type(obj)}) found for {path}")
 
 
-def _get_kwargs(config: Union[ObjectConf, DictConfig], **kwargs: Any) -> Any:
+def _get_cls_name(config: Any, pop: bool = True) -> str:
+    if "_target_" not in config:
+        raise InstantiationException("Input config does not have a `_target_` field")
 
-    if isinstance(config, ObjectConf):
-        config = OmegaConf.structured(config)
-        if config.params is not None:
-            params = config.params
-        else:
-            params = OmegaConf.create()
+    if pop:
+        classname = config.pop("_target_")
     else:
-        config = copy.deepcopy(config)
-        if "params" in config:
-            msg = (
-                "\nField 'params' is deprecated since Hydra 1.0 and will be removed in Hydra 1.1."
-                "\nInline the content of params directly at the containing node."
-                "\nSee https://hydra.cc/docs/next/upgrades/0.11_to_1.0/object_instantiation_changes"
-            )
-            warnings.warn(category=UserWarning, message=msg)
-            params = config.params
-        else:
-            params = config
-
-    assert isinstance(
-        params, DictConfig
-    ), f"Input config params are expected to be a mapping, found {type(config.params).__name__}"
-
-    config_overrides = {}
-    passthrough = {}
-    for k, v in kwargs.items():
-        if k in params and get_ref_type(params, k) is not Any:
-            config_overrides[k] = v
-        else:
-            passthrough[k] = v
-    final_kwargs = {}
-
-    with read_write(params):
-        params.merge_with(config_overrides)
-
-    for k, v in params.items_ex(resolve=False):
-        if k == "_target_":
-            continue
-        final_kwargs[k] = v
-
-    for k, v in passthrough.items():
-        final_kwargs[k] = v
-
-    for k, v in passthrough.items():
-        final_kwargs[k] = v
-    return final_kwargs
-
-
-def _get_cls_name(config: DictConfig, pop: bool = True) -> str:
-    def _getcls(field: str) -> str:
-        if pop:
-            classname = config.pop(field)
-        else:
-            classname = config[field]
-        if not isinstance(classname, str):
-            raise InstantiationException(f"_target_ field '{field}' must be a string")
-        return classname
-
-    for field in ["target", "cls", "class"]:
-        if field in config:
-            key = config._get_full_key(field)
-            msg = (
-                f"\nConfig key '{key}' is deprecated since Hydra 1.0 and will be removed in Hydra 1.1."
-                f"\nUse '_target_' instead of '{field}'."
-                f"\nSee https://hydra.cc/docs/next/upgrades/0.11_to_1.0/object_instantiation_changes"
-            )
-            warnings.warn(message=msg, category=UserWarning)
-
-    if "_target_" in config:
-        return _getcls("_target_")
-
-    for field in ["target", "cls", "class"]:
-        if field in config:
-            return _getcls(field)
-
-    raise InstantiationException("Input config does not have a `_target_` field")
+        classname = config["_target_"]
+    if not isinstance(classname, str):
+        raise InstantiationException("_target_ field type must be a string")
+    return classname
