@@ -18,14 +18,18 @@ from subprocess import PIPE, Popen
 from typing import Any, Callable, Dict, Iterator, List, Optional, Tuple, Union
 
 from omegaconf import Container, DictConfig, OmegaConf
-from typing_extensions import Protocol
 
 from hydra._internal.hydra import Hydra
 from hydra._internal.utils import detect_task_name
 from hydra.core.global_hydra import GlobalHydra
-from hydra.core.utils import JobReturn, split_config_path
+from hydra.core.utils import JobReturn, validate_config_path
 from hydra.types import TaskFunction
 
+if sys.version_info >= (3, 8, 0):
+    from typing import Protocol
+else:
+    from typing_extensions import Protocol  # type: ignore
+
 
 @contextmanager
 def does_not_raise(enter_result: Any = None) -> Iterator[Any]:
@@ -44,7 +48,6 @@ class TaskTestFunction:
         self.calling_module: Optional[str] = None
         self.config_path: Optional[str] = None
         self.config_name: Optional[str] = None
-        self.strict: Optional[bool] = None
         self.hydra: Optional[Hydra] = None
         self.job_ret: Optional[JobReturn] = None
         self.configure_logging: bool = False
@@ -58,25 +61,22 @@ class TaskTestFunction:
 
     def __enter__(self) -> "TaskTestFunction":
         try:
-            config_dir, config_name = split_config_path(
-                self.config_path, self.config_name
-            )
+            validate_config_path(self.config_path)
 
             job_name = detect_task_name(self.calling_file, self.calling_module)
 
             self.hydra = Hydra.create_main_hydra_file_or_module(
                 calling_file=self.calling_file,
                 calling_module=self.calling_module,
-                config_path=config_dir,
+                config_path=self.config_path,
                 job_name=job_name,
-                strict=self.strict,
             )
             self.temp_dir = tempfile.mkdtemp()
             overrides = copy.deepcopy(self.overrides)
             assert overrides is not None
             overrides.append(f"hydra.run.dir={self.temp_dir}")
             self.job_ret = self.hydra.run(
-                config_name=config_name,
+                config_name=self.config_name,
                 task_function=self,
                 overrides=overrides,
                 with_log_configuration=self.configure_logging,
@@ -101,7 +101,6 @@ class TTaskRunner(Protocol):
         config_path: Optional[str],
         config_name: Optional[str],
         overrides: Optional[List[str]] = None,
-        strict: Optional[bool] = None,
         configure_logging: bool = False,
     ) -> TaskTestFunction:
         ...
@@ -123,7 +122,6 @@ class SweepTaskFunction:
         self.task_function: Optional[TaskFunction] = None
         self.config_path: Optional[str] = None
         self.config_name: Optional[str] = None
-        self.strict: Optional[bool] = None
         self.sweeps = None
         self.returns = None
         self.configure_logging: bool = False
@@ -146,21 +144,18 @@ class SweepTaskFunction:
         overrides.append(f"hydra.sweep.dir={self.temp_dir}")
 
         try:
-            config_dir, config_name = split_config_path(
-                self.config_path, self.config_name
-            )
+            validate_config_path(self.config_path)
             job_name = detect_task_name(self.calling_file, self.calling_module)
 
             hydra_ = Hydra.create_main_hydra_file_or_module(
                 calling_file=self.calling_file,
                 calling_module=self.calling_module,
-                config_path=config_dir,
+                config_path=self.config_path,
                 job_name=job_name,
-                strict=self.strict,
             )
 
             self.returns = hydra_.multirun(
-                config_name=config_name,
+                config_name=self.config_name,
                 task_function=self,
                 overrides=overrides,
                 with_log_configuration=self.configure_logging,
@@ -188,7 +183,6 @@ class TSweepRunner(Protocol):
         config_path: Optional[str],
         config_name: Optional[str],
         overrides: Optional[List[str]],
-        strict: Optional[bool] = None,
         temp_dir: Optional[Path] = None,
     ) -> SweepTaskFunction:
         ...
@@ -276,7 +270,7 @@ def integration_test(
     expected_outputs: Union[str, List[str]],
     prolog: Union[None, str, List[str]] = None,
     filename: str = "task.py",
-    env_override: Dict[str, str] = {},
+    env_override: Optional[Dict[str, str]] = None,
     clean_environment: bool = False,
     generate_custom_cmd: Callable[..., List[str]] = lambda cmd, *args, **kwargs: cmd,
 ) -> str:
@@ -296,7 +290,7 @@ from hydra.core.hydra_config import HydraConfig
 
 $PROLOG
 
-@hydra.main(config_name='config')
+@hydra.main(config_path='.', config_name='config')
 def experiment(cfg):
     with open("$OUTPUT_FILE", "w") as f:
 $PRINTS
@@ -335,7 +329,8 @@ if __name__ == "__main__":
             modified_env = {}
         else:
             modified_env = os.environ.copy()
-            modified_env.update(env_override)
+            if env_override is not None:
+                modified_env.update(env_override)
         subprocess.check_call(cmd, env=modified_env)
 
         with open(output_file, "r") as f:
@@ -365,14 +360,27 @@ def run_with_error(cmd: Any, env: Any = None) -> str:
     return err
 
 
-def get_run_output(
-    cmd: Any, env: Any = None, allow_warnings: bool = False
+def run_python_script(
+    cmd: Any,
+    env: Any = None,
+    allow_warnings: bool = False,
+    print_error: bool = True,
+    raise_exception: bool = True,
 ) -> Tuple[str, str]:
     if allow_warnings:
         cmd = [sys.executable] + cmd
     else:
         cmd = [sys.executable, "-Werror"] + cmd
+    return run_process(cmd, env, print_error, raise_exception)
 
+
+def run_process(
+    cmd: Any,
+    env: Any = None,
+    print_error: bool = True,
+    raise_exception: bool = True,
+    timeout: Optional[float] = None,
+) -> Tuple[str, str]:
     try:
         process = subprocess.Popen(
             args=cmd,
@@ -381,16 +389,21 @@ def get_run_output(
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
         )
-        bstdout, bstderr = process.communicate()
+        bstdout, bstderr = process.communicate(timeout=timeout)
         stdout = normalize_newlines(bstdout.decode().rstrip())
         stderr = normalize_newlines(bstderr.decode().rstrip())
         if process.returncode != 0:
-            sys.stderr.write(f"Subprocess error:\n{stderr}\n")
-            raise subprocess.CalledProcessError(returncode=process.returncode, cmd=cmd)
+            if print_error:
+                sys.stderr.write(f"Subprocess error:\n{stderr}\n")
+            if raise_exception:
+                raise subprocess.CalledProcessError(
+                    returncode=process.returncode, cmd=cmd
+                )
         return stdout, stderr
     except Exception as e:
-        cmd = " ".join(cmd)
-        print(f"==Error executing==\n{cmd}\n===================")
+        if print_error:
+            cmd = " ".join(cmd)
+            sys.stderr.write(f"=== Error executing:\n{cmd}\n===================")
         raise e
 
 
@@ -451,3 +464,21 @@ def assert_regex_match(
                 from_name=from_name,
                 to_name=to_name,
             )
+
+
+def assert_multiline_regex_search(
+    pattern: str, string: str, from_name: str = "Expected", to_name: str = "Actual"
+) -> None:
+    """Check that `pattern` (which can be a regex expression)
+    matches the corresponding lines of `string` string.
+    In case the regex match fails, we display the diff as if `pattern` was a regular string.
+    """
+    pattern = normalize_newlines(pattern)
+    string = normalize_newlines(string)
+    if re.search(pattern, string, flags=re.MULTILINE) is None:
+        print("\n-------- PATTERN: -----------")
+        print(pattern)
+        print("---------- STRING: ------------")
+        print(string)
+        print("-------------------------------")
+        assert False, "Regex pattern did not match"
